@@ -3,7 +3,7 @@ import re
 
 import questionary as questionary
 import yaml
-from questionary import Separator
+from questionary import Separator, prompt
 from yaml.scanner import ScannerError
 
 from iauditor_exporter.modules.global_variables import *
@@ -206,9 +206,9 @@ def load_setting_media_sync_offset(logger, config_settings):
             "media_sync_offset_in_seconds"
         ]
         if (
-            media_sync_offset is None
-            or media_sync_offset < 0
-            or not isinstance(media_sync_offset, int)
+                media_sync_offset is None
+                or media_sync_offset < 0
+                or not isinstance(media_sync_offset, int)
         ):
             media_sync_offset = DEFAULT_MEDIA_SYNC_OFFSET_IN_SECONDS
         return media_sync_offset
@@ -234,17 +234,17 @@ def parse_export_filename(audit_json, filename_item_id):
     # When this item ID is specified in the custom export filename configuration, the audit_data.name property
     # will be used to populate the data as it covers all cases.
     if (
-        filename_item_id == AUDIT_TITLE_ITEM_ID
-        and "audit_data" in audit_json.keys()
-        and "name" in audit_json["audit_data"].keys()
+            filename_item_id == AUDIT_TITLE_ITEM_ID
+            and "audit_data" in audit_json.keys()
+            and "name" in audit_json["audit_data"].keys()
     ):
         return audit_json["audit_data"]["name"].replace("/", "_")
     for item in audit_json["header_items"]:
         if item["item_id"] == filename_item_id:
             if "responses" in item.keys():
                 if (
-                    "text" in item["responses"].keys()
-                    and item["responses"]["text"].strip() != ""
+                        "text" in item["responses"].keys()
+                        and item["responses"]["text"].strip() != ""
                 ):
                     return item["responses"]["text"]
     return None
@@ -500,13 +500,13 @@ def load_config_settings(logger, path_to_config_file, docker_enabled=False):
             ACTIONS_TABLE: load_actions_table(
                 config_settings["export_options"]["sql_table"]
             )
-            + "_actions",
+                           + "_actions",
             ACTIONS_MERGE_ROWS: config_settings["export_options"]["actions_merge_rows"],
         }
     return settings
 
 
-def configure(logger, path_to_config_file, export_formats, docker_enabled):
+def configure(logger, path_to_config_file, export_formats, docker_enabled, chunks):
     """
     instantiate and configure logger, load config settings from file, instantiate SafetyCulture SDK
     :param logger:              the logger
@@ -517,9 +517,10 @@ def configure(logger, path_to_config_file, export_formats, docker_enabled):
 
     config_settings = load_config_settings(logger, path_to_config_file, docker_enabled)
     config_settings[EXPORT_FORMATS] = export_formats
+    config_settings['chunks'] = chunks
     if (
-        config_settings[PROXY_HTTP] is not None
-        and config_settings[PROXY_HTTPS] is not None
+            config_settings[PROXY_HTTP] is not None
+            and config_settings[PROXY_HTTPS] is not None
     ):
         proxy_settings = {
             "http": config_settings[PROXY_HTTP],
@@ -628,13 +629,13 @@ def parse_command_line_arguments(logger):
         "--format",
         nargs="*",
         help="formats to download, valid options are pdf, "
-        "json, docx, csv, media, web-report-link, actions, pickle, sql",
+             "json, docx, csv, media, web-report-link, actions, pickle, sql",
     )
     parser.add_argument(
         "--list_preferences",
         nargs="*",
         help="display all preferences, or restrict to specific"
-        " template_id if supplied as additional argument",
+             " template_id if supplied as additional argument",
     )
     parser.add_argument(
         "--loop", nargs="*", help="execute continuously until interrupted"
@@ -642,6 +643,11 @@ def parse_command_line_arguments(logger):
     parser.add_argument(
         "--setup", action="store_true", help="Helps set up the script with ease."
     )
+    parser.add_argument(
+        "--chunks", type=int, help="Specify a smaller number of chunks when "
+                                   "exporting large numbers of "
+                                   "PDFs, DOCX or Media "
+    )
     args = parser.parse_args()
 
     if args.setup:
@@ -691,6 +697,7 @@ def parse_command_line_arguments(logger):
             else:
                 export_formats.append(option)
 
+    chunks = args.chunks if args.chunks is not None else 100
     loop_enabled = True if args.loop is not None else False
     docker_enabled = True if args.docker is not None else False
 
@@ -700,6 +707,7 @@ def parse_command_line_arguments(logger):
         args.list_preferences,
         loop_enabled,
         docker_enabled,
+        chunks
     )
 
 
@@ -743,11 +751,17 @@ def ask_question(logger, str, q_type, choices=None, special=None, default=""):
 
     elif q_type == "int":
         response = questionary.text(str, default=default).ask()
-        response = int(response)
+        if response:
+            response = int(response)
+        else:
+            response = default
 
     elif q_type == "bool":
         response = questionary.confirm(str).ask()
 
+    elif q_type == "password":
+        response = questionary.password(str).ask()
+
     if special == "config_name":
         response = sanitise_config_name(logger, response)
 
@@ -795,7 +809,7 @@ def setup_database(logger):
 
     if db_type == "mssql":
         db_settings["database_name"] = (
-            db_settings["database_name"] + "?driver=ODBC Driver 17 for SQL Server"
+                db_settings["database_name"] + "?driver=ODBC Driver 17 for SQL Server"
         )
 
     return db_settings
@@ -837,22 +851,22 @@ def update_key(logger, settings, key):
             settings[parent][key] = new_value
         else:
             settings[key] = new_value
-    elif key.startswith(("database_", "sql_")):
-        db_settings = setup_database(logger)
-        print(db_settings)
-        sql_test = test_sql_settings(logger, db_settings)
-        if sql_test:
-            logger.info("Connected successfully, writing settings to config file.")
-            for k, v in db_settings.items():
-                settings["export_options"][k] = v
-        else:
-            logger.warning("Connection unsuccessful, trying again.")
-            setup_database(logger)
+    # elif key.startswith(("database_", "sql_")):
+    #     db_settings = setup_database(logger)
+    #     print(db_settings)
+    #     sql_test = test_sql_settings(logger, db_settings)
+    #     if sql_test:
+    #         logger.info("Connected successfully, writing settings to config file.")
+    #         for k, v in db_settings.items():
+    #             settings["export_options"][k] = v
+    #     else:
+    #         logger.warning("Connection unsuccessful, trying again.")
+    #         setup_database(logger)
     else:
         print(f"{key} is not a recognised setting. If unsure, start a new config file.")
 
 
-def modify_choice(logger, settings, config_path):
+def modify_choice(logger, settings, config_path, default_pos='export_path'):
     options = []
     for k, v in settings.items():
         options.append(Separator())
@@ -863,15 +877,18 @@ def modify_choice(logger, settings, config_path):
                 if inner_k == "sql_table":
                     options.append(Separator())
                 options.append(f"{inner_k} - Current setting: {inner_v}")
-    print("Which setting do you need to modify?")
     exit_no_save = "Exit without saving changes"
     exit_save = "Exit and save"
+    test_sql = "Test database settings"
     if exit_no_save not in options:
-        exit_list = [exit_save, exit_no_save, Separator()]
+        exit_list = [exit_save, exit_no_save, test_sql, Separator()]
         options = exit_list + options
-    to_modify = questionary.select("Select an option to modify:", choices=options).ask()
-    to_modify = to_modify.split("-")[0].strip()
-    if to_modify == exit_save:
+    to_modify = questionary.select("Select an option to modify:", choices=options, default=default_pos).ask()
+    if to_modify:
+        to_modify = to_modify.split("-")[0].strip()
+    else:
+        sys.exit()
+    if to_modify == exit_save or to_modify == test_sql:
         with open(config_path, "w") as file:
             updated_config = yaml.dump(
                 settings, default_flow_style=False, sort_keys=False
@@ -879,8 +896,13 @@ def modify_choice(logger, settings, config_path):
             updated_config = updated_config.replace("-", "")
             updated_config = updated_config.replace("null", "")
             file.write(updated_config.replace("-", ""))
-        logger.info("All done. Re run the tool to use your new configuration. ")
-        sys.exit()
+        if to_modify == test_sql:
+            sql_test_result = test_sql_settings(logger, settings)
+            if not sql_test_result:
+                modify_choice(logger, settings, config_path)
+        else:
+            logger.info("All done. Re run the tool to use your new configuration. ")
+            sys.exit()
     elif to_modify == exit_no_save:
         logger.info("Changes discarded.")
         sys.exit()
@@ -902,7 +924,7 @@ def initial_setup(logger):
 
     # setup variables
     current_directory_path = os.getcwd()
-    print("Setup!")
+    box_print("iAuditor Export Tool Setup")
     exports_folder_name = "configs"
 
     create_directory_if_not_exists(logger, exports_folder_name)
@@ -928,9 +950,10 @@ def initial_setup(logger):
         config_name = settings["config_name"]
     else:
         print(
-            "Your config file is missing config_name. Delete the file, "
-            "re run the tool and it will be recreated correctly."
+            "Your config file is missing config_name. If you delete your config file and "
+            "re run the tool with --setup it will be recreated correctly."
         )
+        sys.exit()
 
     current_ls = get_last_successful(logger, config_name)
     parsed_date = parse_ls(current_ls)
