@@ -68,16 +68,32 @@ questions = {
     },
     "proxy_http": {
         "type": "text",
-        "question": "Proxy Address",
+        "question": "HTTP Proxy Address",
         "header": "Don" "t forget to set the HTTPS proxy, too.",
         "parent": "API",
     },
     "proxy_https": {
         "type": "text",
-        "question": "Proxy Address",
+        "question": "HTTPS Proxy Address",
         "header": "Don" "t forget to set the HTTP proxy, too.",
         "parent": "API",
     },
+    "ssl_cert": {
+        "type": "text",
+        "question": "Client Side Certificates",
+        "header": "If you wish to apply custom SSL certificates to any requests we make, specify the path to them "
+        "here. This is feature is largely untested but works by leveraging this feature of the requests "
+        "module: https://requests.readthedocs.io/en/master/user/advanced/#client-side-certificates ",
+        "parent": "API",
+    },
+    "ssl_verify": {
+        "type": "text",
+        "question": "SSL Cert Verification",
+        "header": "If you wish to apply custom SSL certificate verification to any requests we make, specify the path "
+        "to them here. This is feature is largely untested but works by leveraging this feature of the "
+        "requests module: https://requests.readthedocs.io/en/master/user/advanced/#ssl-cert-verification ",
+        "parent": "API",
+    },
     "config_name": {
         "type": "text",
         "question": "Config Name",
@@ -89,7 +105,7 @@ questions = {
     },
     "export_path": {
         "type": "text",
-        "question": "Config Name",
+        "question": "Export Path",
         "header": """
                     It is usually best to leave this option blank and use the default of the exports folder within the 
                     same folder where you run the tool. If you need to set the path, type it below. The path can be 
@@ -100,11 +116,10 @@ questions = {
     "filename": {
         "type": "multi",
         "question": "When exporting PDFs, how do you want to name the files?",
-        "header": """
-                If you have complex title requirements, you should set them up on your template in iAuditor and
-                select 'Audit Title' below. Don't forget that it's possible to get two inspections with the same name
-                if you use Audit Title. Audit ID is the best option to avoid this. 
-                """,
+        "header": """If you have complex title requirements, you should set them up on your template in iAuditor and 
+        select 'Audit Title' below. Don't forget that it's possible to get two inspections with the same name if you 
+        use Audit Title. Audit ID is the best option to avoid this. If you wish to set a custom ID, please edit the 
+        config file directly. """,
         "options": [
             {"name": "Audit ID", "value": None},
             {"name": "Audit Title", "value": "f3245d40-ea77-11e1-aff1-0800200c9a66"},
@@ -129,7 +144,7 @@ questions = {
                 "value": False,
             },
             {
-                "name": "Export Inspections both in and out of the archive",
+                "name": "Export inspections both in and out of the archive",
                 "value": "both",
             },
             {"name": "Only export inspections in the archive", "value": True},
@@ -143,15 +158,12 @@ questions = {
                 Select how you want completion status to affect your export. 
                 """,
         "options": [
+            {"name": "Only export inspections that are incomplete", "value": False,},
             {
-                "name": "Only export inspections that are not in the archive",
-                "value": False,
-            },
-            {
-                "name": "Export Inspections both in and out of the archive",
+                "name": "Export both complete and incomplete inspections",
                 "value": "both",
             },
-            {"name": "Only export inspections in the archive", "value": True},
+            {"name": "Only export completed inspections", "value": True},
         ],
         "parent": "export_options",
     },
@@ -166,15 +178,13 @@ questions = {
                 """,
         "parent": "export_options",
     },
-    "use_real_template_name": {
+    "export_inactive_items": {
         "type": "bool",
         "question": "Export Inactive Items",
-        "header": """
-                This setting only applies when exporting to CSV. Valid values are true (export all items) or 
-                false (do not export inactive items). Items that are nested under Smart Field will be 'inactive' if the smart 
-                field condition is not satisfied for these items. This option is forced to true if you're using SQL and 
-                enable either of the merge_rows options.
-                """,
+        "header": """This setting only applies when exporting to CSV or SQL. Valid values are true (export all items) 
+        or false (do not export inactive items). Items that are nested under Smart Field will be 'inactive' if the 
+        smart field condition is not satisfied for these items. This option is forced to true if you're using SQL and 
+        enable either of the merge_rows options. """,
         "parent": "export_options",
     },
     "preferences": {
@@ -182,7 +192,7 @@ questions = {
         "question": "Set a Preference",
         "header": """
                 If you wish to apply a preference to exported PDFs and Word Documents, specify the relevant 
-                preference ID here. 
+                preference ID here. To view your preferences, re-run the tool with --list_preferences.
                 """,
         "parent": "export_options",
     },
@@ -218,7 +228,7 @@ questions = {
     },
     "merge_rows": {
         "type": "bool",
-        "question": "Export Inactive Items",
+        "question": "Merge SQL Rows",
         "header": """
                 This setting, when set to true will update existing rows in the database when an inspection is 
                 updated after being logged. There are important caveats to this option, please review the documentation
@@ -229,7 +239,7 @@ questions = {
     },
     "actions_merge_rows": {
         "type": "bool",
-        "question": "Export Inactive Items",
+        "question": "Merge SQL Rows for Actions",
         "header": """
                 This setting, when set to true will update existing rows in the database when an action is 
                 updated after being logged. There are important caveats to this option, please review the documentation
@@ -238,4 +248,76 @@ questions = {
                 """,
         "parent": "export_options",
     },
-}
+    "sql_table": {
+        "type": "text",
+        "question": "Database table name",
+        "header": """This is the name of the table in your database you wish to store your data in. The tool should 
+        be able to create the table for you so whatever you enter here will be used as the name.""",
+        "parent": "export_options",
+    },
+    "database_type": {
+        "type": "multi",
+        "question": "Database Type",
+        "header": """Set the type of database you're using.""",
+        "options": [
+            {"name": "SQL", "value": "mssql"},
+            {"name": "MySQL", "value": "mysql"},
+            {"name": "Postgres", "value": "postgres"},
+        ],
+        "parent": "export_options",
+    },
+    "database_user": {
+        "type": "text",
+        "question": "Database user",
+        "header": """Set the username to use when accessing the database.""",
+        "parent": "export_options",
+    },
+    "database_pwd": {
+        "type": "password",
+        "question": "Database password",
+        "header": """Set the password to use when accessing the database.""",
+        "parent": "export_options",
+    },
+    "database_server": {
+        "type": "text",
+        "question": "Database server",
+        "header": """
+        This option sets the address of your database server. e.g. localhost or 192.168.1.88, for example. 
+        Remember to ensure your database allows remote connections if you're not running the tool on the same box as your database.
+        """,
+        "parent": "export_options",
+    },
+    "database_port": {
+        "type": "text",
+        "question": "Database port",
+        "header": """
+    Specify the port to access your database. For reference, default ports are: 
+    SQL: 1433
+    MySQL: 3308
+    Postgres: 5432
+    """,
+        "parent": "export_options",
+    },
+    "database_schema": {
+        "type": "text",
+        "question": "Database schema",
+        "header": """
+Specify the schema you wish to use. The defaults are: SQL: dbo, MySQL: From tests, this can usually be left blank, 
+Postgres: public.
+""",
+        "parent": "export_options",
+    },
+    "database_name": {
+        "type": "text",
+        "question": "Database name",
+        "header": """
+        This option specifies the name of the database you are using. For Postgres and MySQL, the name 
+        alone is enough. 
+        
+        For SQL, you must specify the driver you wish to use. To do this, type your database name 
+        and follow it with ?driver=ODBC Driver 17 for SQL Server (or other driver depending on your requirements. 
+        For example, if your database name was 'iAuditor', you'd enter: iAuditor?driver=ODBC Driver 17 for SQL Server 
+        """,
+        "parent": "export_options",
+    }
+}
\ No newline at end of file
